# DRAPI-Lemur
 
 DRAPI Lemur is a data request API for the IDR. To distinguish it from other similar data request API repositories, this one has been designated "Lemur", in honor of the IDR's affinity for tree-dwelling mammals 🦥.

# makeDirTemplate Example

Copy and paste the contents of `makeDirTemplate Example` and rename the contained directory named `Rename Me`. Note that `Rename Me` has hidden files, like `.env`.
